"""Diameter-synthesis expceptions."""

# Copyright (C) 2021-2024  Blue Brain Project, EPFL
#
# SPDX-License-Identifier: Apache-2.0


class DiameterSynthesisError(Exception):
    """Base diameter-synthesis exception."""
